==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/Prelude/CReal.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v177	((void*)startLabel+44)
#define FN_LAMBDA174	((void*)startLabel+72)
#define CT_v180	((void*)startLabel+104)
#define CF_LAMBDA174	((void*)startLabel+112)
#define CT_v182	((void*)startLabel+148)
#define CT_v184	((void*)startLabel+192)
#define CT_v186	((void*)startLabel+236)
#define ST_v179	((void*)startLabel+248)
#define ST_v181	((void*)startLabel+298)
#define ST_v183	((void*)startLabel+323)
#define ST_v176	((void*)startLabel+348)
#define ST_v178	((void*)startLabel+369)
#define ST_v185	((void*)startLabel+396)
extern Node TM_Prelude[];
extern Node FN_Prelude_46error[];
extern Node TMSUB_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v177)
,};
Node FN_Prelude_46_95_46toRational[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_ARG_I2,HEAP_CVAL_I3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,2)
, bytes2word(ZAP_ARG_I2,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(ST_v176)
,	/* CT_v177: (byte 0) */
  HW(2,2)
, 0
,};
Node F0_Prelude_46_95_46toRational[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46toRational),2)
, VAPTAG(useLabel(FN_LAMBDA174))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v180)
,	/* FN_LAMBDA174: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v179)
, 0
, useLabel(ST_v178)
,	/* CT_v180: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA174: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA174))
, bytes2word(1,0,0,1)
, useLabel(CT_v182)
,};
Node FN_Prelude_46Real_46Prelude_46Num[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 80025
, useLabel(ST_v181)
,	/* CT_v182: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46Real_46Prelude_46Num[] = {
  CAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Num),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v184)
,};
Node FN_Prelude_46Real_46Prelude_46Ord[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 80025
, useLabel(ST_v183)
,	/* CT_v184: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46Real_46Prelude_46Ord[] = {
  CAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Ord),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v186)
,};
Node FN_Prelude_46toRational[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,3)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 80025
, useLabel(ST_v185)
,	/* CT_v186: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46toRational[] = {
  CAPTAG(useLabel(FN_Prelude_46toRational),1)
,	/* ST_v179: (byte 0) */
  bytes2word(78,111,32,100)
, bytes2word(101,102,97,117)
, bytes2word(108,116,32,100)
, bytes2word(101,102,105,110)
, bytes2word(105,116,105,111)
, bytes2word(110,32,102,111)
, bytes2word(114,32,99,108)
, bytes2word(97,115,115,32)
, bytes2word(109,101,116,104)
, bytes2word(111,100,32,116)
, bytes2word(111,82,97,116)
, bytes2word(105,111,110,97)
,	/* ST_v181: (byte 2) */
  bytes2word(108,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,82,101)
, bytes2word(97,108,46,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,78)
,	/* ST_v183: (byte 3) */
  bytes2word(117,109,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,82)
, bytes2word(101,97,108,46)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
,	/* ST_v176: (byte 4) */
  bytes2word(79,114,100,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,116,111)
, bytes2word(82,97,116,105)
, bytes2word(111,110,97,108)
,	/* ST_v178: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,95,46,116)
, bytes2word(111,82,97,116)
, bytes2word(105,111,110,97)
, bytes2word(108,58,110,111)
,	/* ST_v185: (byte 4) */
  bytes2word(112,111,115,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(116,111,82,97)
, bytes2word(116,105,111,110)
, bytes2word(97,108,0,0)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/Prelude/CReal.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v182	((void*)startLabel+44)
#define FN_LAMBDA179	((void*)startLabel+72)
#define CT_v185	((void*)startLabel+104)
#define CF_LAMBDA179	((void*)startLabel+112)
#define CT_v187	((void*)startLabel+148)
#define CT_v189	((void*)startLabel+192)
#define CT_v191	((void*)startLabel+236)
#define ST_v184	((void*)startLabel+248)
#define ST_v186	((void*)startLabel+298)
#define ST_v188	((void*)startLabel+323)
#define ST_v181	((void*)startLabel+348)
#define ST_v183	((void*)startLabel+369)
#define ST_v190	((void*)startLabel+396)
extern Node TM_Prelude[];
extern Node FN_NHC_46Internal_46_95noMethodError[];
extern Node TMSUB_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v182)
,};
Node FN_Prelude_46_95_46toRational[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_ARG_I2,HEAP_CVAL_I3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,2)
, bytes2word(ZAP_ARG_I2,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(ST_v181)
,	/* CT_v182: (byte 0) */
  HW(2,2)
, 0
,};
Node F0_Prelude_46_95_46toRational[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46toRational),2)
, VAPTAG(useLabel(FN_LAMBDA179))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95noMethodError))
, bytes2word(0,0,0,0)
, useLabel(CT_v185)
,	/* FN_LAMBDA179: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v184)
, 0
, useLabel(ST_v183)
,	/* CT_v185: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA179: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA179))
, bytes2word(1,0,0,1)
, useLabel(CT_v187)
,};
Node FN_Prelude_46Real_46Prelude_46Num[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 80025
, useLabel(ST_v186)
,	/* CT_v187: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46Real_46Prelude_46Num[] = {
  CAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Num),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v189)
,};
Node FN_Prelude_46Real_46Prelude_46Ord[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 80025
, useLabel(ST_v188)
,	/* CT_v189: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46Real_46Prelude_46Ord[] = {
  CAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Ord),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v191)
,};
Node FN_Prelude_46toRational[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,3)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 80025
, useLabel(ST_v190)
,	/* CT_v191: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46toRational[] = {
  CAPTAG(useLabel(FN_Prelude_46toRational),1)
,	/* ST_v184: (byte 0) */
  bytes2word(78,111,32,100)
, bytes2word(101,102,97,117)
, bytes2word(108,116,32,100)
, bytes2word(101,102,105,110)
, bytes2word(105,116,105,111)
, bytes2word(110,32,102,111)
, bytes2word(114,32,99,108)
, bytes2word(97,115,115,32)
, bytes2word(109,101,116,104)
, bytes2word(111,100,32,116)
, bytes2word(111,82,97,116)
, bytes2word(105,111,110,97)
,	/* ST_v186: (byte 2) */
  bytes2word(108,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,82,101)
, bytes2word(97,108,46,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,78)
,	/* ST_v188: (byte 3) */
  bytes2word(117,109,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,82)
, bytes2word(101,97,108,46)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
,	/* ST_v181: (byte 4) */
  bytes2word(79,114,100,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,116,111)
, bytes2word(82,97,116,105)
, bytes2word(111,110,97,108)
,	/* ST_v183: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,95,46,116)
, bytes2word(111,82,97,116)
, bytes2word(105,111,110,97)
, bytes2word(108,58,110,111)
,	/* ST_v190: (byte 4) */
  bytes2word(112,111,115,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(116,111,82,97)
, bytes2word(116,105,111,110)
, bytes2word(97,108,0,0)
,};
